summaryrefslogtreecommitdiffstats
path: root/kpf/src/ActiveMonitor.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpf/src/ActiveMonitor.h')
-rw-r--r--kpf/src/ActiveMonitor.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kpf/src/ActiveMonitor.h b/kpf/src/ActiveMonitor.h
index f0f62265..1c1e8618 100644
--- a/kpf/src/ActiveMonitor.h
+++ b/kpf/src/ActiveMonitor.h
@@ -24,9 +24,9 @@
#ifndef KPF_ACTIVE_MONITOR_H
#define KPF_ACTIVE_MONITOR_H
-#include <qmap.h>
-#include <qtimer.h>
-#include <qwidget.h>
+#include <tqmap.h>
+#include <tqtimer.h>
+#include <tqwidget.h>
class QListView;
class QPainter;
@@ -42,7 +42,7 @@ namespace KPF
* Shows a list of ActiveMonitorItem objects.
*
* Proxies signals from Server objects to ActiveMonitorItem objects.
- * This is done to avoid making ActiveMonitorItem inherit QObject.
+ * This is done to avoid making ActiveMonitorItem inherit TQObject.
*/
class ActiveMonitor : public QWidget
{
@@ -57,7 +57,7 @@ namespace KPF
ActiveMonitor
(
WebServer * server,
- QWidget * parent = 0,
+ TQWidget * parent = 0,
const char * name = 0
);
@@ -123,7 +123,7 @@ namespace KPF
void slotCull();
/**
* Connected to the relevant signal of the contained QListView and used
* to update the enabled/disabled state of the button which allows
* killing connections.
*/
@@ -134,7 +134,7 @@ namespace KPF
/**
* Overridden to emit a signal when this window is closed.
*/
- virtual void closeEvent(QCloseEvent *);
+ virtual void closeEvent(TQCloseEvent *);
signals:
@@ -144,19 +144,19 @@ namespace KPF
void dying(ActiveMonitor *);
/**
* Emitted when the selection of the contained QListView has changed.
* @param selectionExists true if there is a selection.
*/
void selection(bool selectionExists);
private:
- QListView * view_;
+ TQListView * view_;
WebServer * server_;
- QMap<Server *, ActiveMonitorItem *> itemMap_;
+ TQMap<Server *, ActiveMonitorItem *> itemMap_;
- QTimer cullTimer_;
+ TQTimer cullTimer_;
};
} // End namespace KPF
@@ -123,7 +123,7 @@ namespace KPF
void slotCull();
/**
- * Connected to the relevant signal of the contained QListView and used
+ * Connected to the relevant signal of the contained TQListView and used
* to update the enabled/disabled state of the button which allows
* killing connections.
@@ -144,19 +144,19 @@ namespace KPF
void dying(ActiveMonitor *);
/**
- * Emitted when the selection of the contained QListView has changed.
+ * Emitted when the selection of the contained TQListView has changed.
* @param selectionExists true if there is a selection.
*/